
## CATO-CLI - mutation.site.removeNetworkRange:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.site.removeNetworkRange) for documentation on this operation.

### Usage for mutation.site.removeNetworkRange:

```bash
catocli mutation site removeNetworkRange -h

catocli mutation site removeNetworkRange <json>

catocli mutation site removeNetworkRange --json-file mutation.site.removeNetworkRange.json

catocli mutation site removeNetworkRange '{"networkRangeId":"id"}'

catocli mutation site removeNetworkRange '{
    "networkRangeId": "id"
}'
```

#### Operation Arguments for mutation.site.removeNetworkRange ####

`accountId` [ID] - (required) N/A    
`networkRangeId` [ID] - (required) N/A    
